////////////////////////////////////////////////////////////
//                                                        //
// Catalog of the fake "terraformed" Solar system         //
// for SpaceEngine                                        //
//                                                        //
// Modifying some bodies in the default catalog           //
// Updated 25 March 2016                                  //
//                                                        //
////////////////////////////////////////////////////////////

// Star solver log level:
// 0 - do not log
// 1 - log errors and warnings only
// 2 - log everything
LogLevel    2

// Mercury is modified to use procedural surface texture,
// atmosphere, clouds, water and life added

Planet	"Mercury"
{
	ParentBody     "Sol"
	Class          "Terra"

	Albedo          0.68
	Brightness		2.5

	Color         ( 0.850 0.850 1.000 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
		Panspermia true
	}

	Surface
	{
		DiffMap        "NONE" // use procedural texture
		DiffMapAlpha   "Water"
		SurfStyle       0.0
		Randomize       (0.86 0.43 0.75)
        colorSea        (0.02 0.05 0.10 1.00)
        colorShelf      (0.15 0.48 0.46 1.00)
        colorBeach      (0.82 0.73 0.57 0.00)
        colorDesert     (0.42 0.36 0.22 0.00)
        colorLowland    (0.34 0.29 0.18 0.00)
        colorUpland     (0.57 0.54 0.42 0.00)
        colorRock       (0.10 0.10 0.10 0.00)
        colorSnow       (1.00 1.00 1.00 0.50)
        colorLowPlants  (0.18 0.24 0.09 0.00)
        colorUpPlants   (0.15 0.17 0.07 0.00)
        climateEquator  0.642
        climateTropic   0.1422
        climatePole     0.9
        tropicWidth     0.21
		snowLevel       0.95
		mareDensity     0.0
		erosion         0.12
		craterMagn      0.46
		craterFreq      12.87582
		craterDensity   0.8416469
		craterOctaves   10
		craterRayedFactor 0.0
		Hapke           0.0

		// Elevation map author: Sean Young "HarbingerDawn"
		BumpMap        "Mercury/Bump-fake-HD"
		BumpTileSize    258
		BumpTileBorder  1
		BumpHeight      10.289
		BumpOffset		5.889
	}

	Ocean
	{
		Height          5.5
	}

	Clouds
	{
		Height          17.0
		Velocity       -80 // km/h
		Coverage        0.45
		ModulateColor  (1 1 1 1)
		TidalLocked     true
	}

	Atmosphere
	{
		Height      120		// km
		Greenhouse  0		// degrees K
		Pressure    0.52	// atm
		Model      "Earth"
		Bright      5.0
		Opacity     1.0
		SkyLight    2.0
		Hue        -0.03

		Composition // values in percent
		{
			N2  56.96
			O2  40.38
			Ar  2.4
			H2O 0.2
			CO2 0.06
		}
	}

	NoAurora        true
}

// Venus is modified to use procedural surface texture,
// atmosphere, clouds, water and life added

Planet	"Venus"
{
	ParentBody     "Sol"
	Class          "Terra"

	Albedo          0.42
	Brightness      2.5

	Color         ( 0.850 0.850 1.000 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
		Panspermia true
	}

	Surface
	{
		DiffMap        "NONE" // use procedural texture
		DiffMapAlpha   "Water"
		SurfStyle       0.0
		OceanStyle      0.0
		Randomize       (0.86 0.43 0.75)
        colorSea        (0.02 0.05 0.10 1.00)
        colorShelf      (0.15 0.48 0.46 1.00)
        colorBeach      (0.82 0.73 0.57 0.00)
        colorDesert     (0.42 0.36 0.22 0.00)
        colorLowland    (0.34 0.29 0.18 0.00)
        colorUpland     (0.57 0.54 0.42 0.00)
        colorRock       (0.10 0.10 0.10 0.00)
        colorSnow       (1.00 1.00 1.00 0.50)
        colorLowPlants  (0.18 0.24 0.09 0.00)
        colorUpPlants   (0.15 0.17 0.07 0.00)
        climateEquator  0.642
        climateTropic   0.1422
        climatePole     0.9
		snowLevel       0.95
        tropicWidth     0.21
		Hapke           0.0
		
		// Elevation map author: Vladimir Romanyuk "SpaceEngineer"
		BumpMap        "Venus/Bump-SE"
		BumpTileSize    258
		BumpTileBorder  1
		BumpHeight      13.7
		BumpOffset		2.9
	}

	Ocean
	{
		Height    4.45
	}

	Clouds
	{
		DiffMap        "NONE"	// use procedural texture
		DiffMapAlpha   "Transp"	// transparent clouds
		Height          7.0
		Velocity       -60 // km/h
		Coverage        0.4
		ModulateColor  (1 1 1 1)
		TidalLocked     true
	}

	Atmosphere
	{
		Height      60		// km
		Greenhouse  8		// degrees K
		Pressure    3.52	// atm
		Adiabat     0.28
		Model      "Earth"
		Bright      10.0
		Opacity     1.0
		SkyLight    3.0
		Hue         0.025
		
		Composition // values in percent
		{
			N2  92.386
			O2  5.97
			Ar  0.142
			H2O 1.5
			CO2 0.002
		}
	}

	Aurora
	{
		Height       100   // km
        TopColor    (0.5 0.5 0.5)	// multiplier
        BottomColor (0.0 1.0 0.0)	// color

		NorthLat     85    // degrees
		NorthLon    -113   // degrees
		NorthRadius  2000  // km
		NorthWidth   600   // km
		NorthRings   3     // number of rings
		NorthBright  0.3

		SouthLat    -82    // degrees
		SouthLon     138   // degrees
		SouthRadius  2000  // km
		SouthWidth   600   // km
		SouthRings   3     // number of rings
		SouthBright  0.3
	}
}

// Earth is modified to use procedural surface texture

Planet	"Earth"
{
	ParentBody      "Earth-Moon"

	Color         ( 0.850 0.850 1.000 )

	Surface
	{
		DiffMap        "NONE"	// use procedural texture
		DiffMapAlpha   "Water"
		SurfStyle       0.1
		OceanStyle      0.0
		Randomize       (0.48 0.15 0.93)
		snowLevel       0.7
		climateEquator  0.625
		climateTropic   0.5
		climatePole     1.0
		tropicWidth     0.07
		latIceCap       0.9
		colorSea        (0.04 0.10 0.20 1.00)
		colorShelf      (0.15 0.48 0.46 1.00)
        colorBeach      (0.82 0.73 0.57 0.00)
        colorDesert     (0.42 0.36 0.22 0.00)
        colorLowland    (0.34 0.29 0.18 0.00)
        colorUpland     (0.57 0.54 0.42 0.00)
        colorRock       (0.10 0.10 0.10 0.00)
        colorSnow       (1.00 1.00 1.00 0.50)
        colorLowPlants  (0.18 0.24 0.09 0.00)
        colorUpPlants   (0.15 0.17 0.07 0.00)
	}
}

// Moon is modified to use procedural surface texture,
// atmosphere, clouds, water and life added

Moon	"Moon"
{
	ParentBody      "Earth-Moon"
	Class	        "Terra"

	Color         ( 0.850 0.850 1.000 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
		Panspermia true
	}

	Surface
	{
		DiffMap        "NONE"	// use procedural texture
		DiffMapAlpha   "Water"
		SurfStyle       0.1
		OceanStyle      0.0
		Randomize       (0.86 0.43 0.75)
		snowLevel       0.95
        colorSea        (0.02 0.05 0.10 1.00)
        colorShelf      (0.15 0.48 0.46 1.00)
        colorBeach      (0.82 0.73 0.57 0.00)
        colorDesert     (0.42 0.36 0.22 0.00)
        colorLowland    (0.34 0.29 0.18 0.00)
        colorUpland     (0.57 0.54 0.42 0.00)
        colorRock       (0.10 0.10 0.10 0.00)
        colorSnow       (1.00 1.00 1.00 0.50)
        colorLowPlants  (0.18 0.24 0.09 0.00)
        colorUpPlants   (0.15 0.17 0.07 0.00)
		Hapke           0.0
	}

	Ocean
	{
		Height          6.5
	}

	Clouds
	{
		Velocity        45
		Height          4.0
		Coverage        0.4
		cycloneDensity  0.0
	}

	NoAurora        true

	Atmosphere
	{
		Height      160		// km
		Greenhouse  35		// degrees K
		Pressure    0.3		// atm
		Adiabat     0.28
		Model      "Earth"
		Bright      5.0
		Opacity     1.0
		SkyLight    1.0
		Hue        -0.05
		
		Composition // values in percent
		{
			N2  28.75
			O2  70.5
			Ar  0.1
			H2O 0.6
			CO2 0.05
		}
	}
}

Moon  "Moonlet"
{
	ParentBody "Moon"
	Class	"Asteroid"
	Radius  100
	
	Orbit
	{
		SemiMajorAxis 3.333e-5
		Inclination   0
		AscendingNode 0
	}
}

// Mars is modified to use procedural surface texture,
// new atmosphere, clouds, water and life added

Planet	"Mars"
{
	ParentBody     "Sol"
	Class          "Terra"

	Color         ( 0.850 0.850 1.000 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Marine/Terrestrial"
		Panspermia true
	}

	Surface
	{
		DiffMap        "NONE" // use procedural texture
		DiffMapAlpha   "Water"
        colorSea        (0.02 0.05 0.10 1.00)
        colorShelf      (0.15 0.48 0.46 1.00)
		colorBeach      (0.40 0.33 0.28 0.00)
		colorDesert     (0.26 0.24 0.22 0.00)
		colorLowland    (0.50 0.42 0.35 0.00)
		colorUpland     (0.62 0.46 0.29 0.00)
		colorRock       (0.68 0.50 0.29 0.00)
		colorSnow       (1.00 1.00 1.00 1.00)
        colorLowPlants  (0.18 0.24 0.09 0.00)
        colorUpPlants   (0.15 0.17 0.07 0.00)
        climateEquator  0.642
		climateTropic   0.350
		climatePole     1.0
		snowLevel       0.49
		tropicLatitude  0.449631
        tropicWidth     0.21
		Hapke           0.0
	}

	Ocean
	{
		Height          8.84
	}

	Clouds
	{
		DiffMap        "NONE"	// use procedural texture
		Height          15
		Velocity        40
		Coverage        0.3
		ModulateColor  (1 1 1 1)	// reset back to defaults
	}

	Atmosphere
	{
		Height      100		// km
		Greenhouse  75		// degrees K
		Pressure    2.7		// atm
		Model      "Neptune"
		Bright      10.0
		Opacity     1.0
		SkyLight    3.0
		
		Composition // values in percent
		{
			N2  84.0
			O2  8.1
			Ar  4.5
			H2O 2.6
			CO2 0.8
		}
	}
}

// Ceres is removed and new Ceres is added as a Mars moon

Remove "Ceres" { ParentBody "Sol" }

Moon	"Ceres"
{
	ParentBody     "Mars"
	Class          "Selena"

	Mass            0.0001579
	Radius          470.925 // 487.5
	Oblateness      0.068

	Orbit
	{
		SemiMajorAxis    0.0003333
		Eccentricity     0.0001
		Inclination      0.8
		AscendingNode    80.3301
		ArgOfPericenter  72.1671
		MeanAnomaly      327.854
	}
}

// Io is modified - atmosphere and life added
Moon	"Io"
{
	ParentBody     "Jupiter"

	Albedo          0.28
	Brightness      3.0

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Terrestrial"
		Panspermia true
	}

	Atmosphere
	{
		Height      120		// km
		Greenhouse  160		// degrees K
		Pressure    0.8		// atm
		Model      "Mars"
		Bright      5.0
		Opacity     1.0
		SkyLight    2.0

		Composition // values in percent
		{
			N2   60.2
			O2   26.1
			Ar   3.5
			CO2  12.2
			SO2  6.7
			SO   1.3
		}
	}

	Aurora
	{
		Height       120   // km
        TopColor    (0.5 0.5 0.5)	// multiplier
        BottomColor (0.0 1.0 0.0)	// color

		NorthLat     0     // degrees
		NorthLon     90    // degrees
		NorthRadius  700   // km
		NorthWidth   400   // km
		NorthRings   4     // number of rings
		NorthBright  0.8

		SouthLat     0     // degrees
		SouthLon     90    // degrees
		SouthRadius  1200  // km
		SouthWidth   400   // km
		SouthRings   4     // number of rings
		SouthBright  0.8
	}
}

// Europa is modified - atmosphere and life added
Moon	"Europa"
{
	ParentBody     "Jupiter"
	Albedo          0.3
	Brightness      1.2

	Color         ( 0.9 0.9 1.0 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Subglacial/Terrestrial"
		Panspermia true
	}

	Clouds
	{
		Height          6.0
		Velocity        82 // km/h
		Coverage        0.2
		cycloneDensity  0.0
	}

	Atmosphere
	{
		Height      120		// km
		Greenhouse  145		// degrees K
		Pressure    0.28	// atm
		Model      "Earth"
		Bright      10.0
		Opacity     1.0
		SkyLight    2.0

		Composition // values in percent
		{
			N2  10.5
			O2  75.0
			Ar  12.2
			H2O 1.7
			CO2 0.6
		}
	}

	Aurora
	{
		Height       100   // km
        TopColor    (0.5 0.5 0.5)	// multiplier
        BottomColor (0.0 1.0 0.0)	// color

		NorthLat     0     // degrees
		NorthLon     90    // degrees
		NorthRadius  700   // km
		NorthWidth   400   // km
		NorthRings   4     // number of rings
		NorthBright  0.4

		SouthLat     0     // degrees
		SouthLon     90    // degrees
		SouthRadius  1200  // km
		SouthWidth   400   // km
		SouthRings   4     // number of rings
		SouthBright  0.4
	}
}

// Ganymede is modified - atmosphere and life added
Moon	"Ganymede"
{
	ParentBody     "Jupiter"

	Albedo          0.25
	Brightness      1.2

	Color         ( 0.9 0.9 1.0 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Terrestrial"
		Panspermia true
	}

	Clouds
	{
		Height          8.0
		Velocity        62 // km/h
		Coverage        0.20
		cycloneDensity  0.0
	}

	Atmosphere
	{
		Height      100		// km
		Greenhouse  140		// degrees K
		Pressure    0.7		// atm
		Model      "Neptune"
		Bright      10.0
		Opacity     1.0
		SkyLight    2.0

		Composition // values in percent
		{
			N2  54.6
			O2  30.0
			Ar  14.1
			H2O 0.9
			CO2 0.4
		}
	}

	Aurora
	{
		Height       80    // km
        TopColor    (0.5 0.5 0.5)	// multiplier
        BottomColor (0.0 1.0 0.0)	// color

		NorthLat     85    // degrees
		NorthLon    -113   // degrees
		NorthRadius  1000  // km
		NorthWidth   600   // km
		NorthRings   3     // number of rings
		NorthBright  0.25

		SouthLat    -82    // degrees
		SouthLon     138   // degrees
		SouthRadius  1000  // km
		SouthWidth   600   // km
		SouthRings   3     // number of rings
		SouthBright  0.25
	}
}

// Callisto is modified - atmosphere and life added
Moon	"Callisto"
{
	ParentBody     "Jupiter"

	Albedo          0.2
	Brightness      2.0

	Color         ( 0.9 0.9 1.0 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Terrestrial"
		Panspermia true
	}

	Clouds
	{
		Height          8.0
		Velocity        42 // km/h
		Coverage        0.20
		cycloneDensity  0.0
	}

	Atmosphere
	{
		Height      100		// km
		Greenhouse  140		// degrees K
		Pressure    0.64	// atm
		Model      "Earth"
		Bright      10.0
		Opacity     1.0
		SkyLight    2.0

		Composition // values in percent
		{
			N2  52.4
			O2  32.8
			Ar  13.7
			H2O 0.8
			CO2 0.3
		}
	}

	NoAurora        true
}

// Triton is modified - atmosphere and life added
Moon	"Triton/Neptune I"
{
	ParentBody     "Neptune"

	Albedo          0.4
	Brightness      1.5

	Color         ( 0.9 0.9 1.0 )

	Life
	{
		Class   "Organic"
		Type    "Multicellular"
		Biome   "Terrestrial"
		Panspermia true
	}

	Clouds
	{
		Height    2.0
		Velocity  80 // km/h
		Coverage  0.12
	}

	Atmosphere
	{
		Height      90		// km
		Greenhouse  150		// degrees K
		Pressure    0.2		// atm
		Adiabat     0.28
		Model      "Earth"
		Bright      7.0
		Opacity     1.0
		SkyLight    2.0
		Hue        -0.025
		
		Composition // values in percent
		{
			N2  3e-5
			O2  99.90997
			Ar  0.5
			H2O 0.02
			CO2 0.07
		}
	}

	Aurora
	{
		Height       120   // km
        TopColor    (0.5 0.5 0.5)	// multiplier
        BottomColor (0.0 1.0 0.0)	// color

		NorthLat     0     // degrees
		NorthLon    -90    // degrees
		NorthRadius  600   // km
		NorthWidth   300   // km
		NorthRings   4     // number of rings
		NorthBright  0.15

		SouthLat     0     // degrees
		SouthLon    -90    // degrees
		SouthRadius  1000  // km
		SouthWidth   300   // km
		SouthRings   4     // number of rings
		SouthBright  0.15
	}
}
